@@ -1,13 +1,13 @@
 package CGI::Session;
 
-# $Id: Session.pm 225 2005-09-16 08:17:15Z sherzodr $
+# $Id: /local/cgi-session/trunk/lib/CGI/Session.pm 273 2006-02-16T03:30:35.734419Z mark  $
 
 use strict;
 use Carp;
 use CGI::Session::ErrorHandler;
 
 @CGI::Session::ISA      = qw( CGI::Session::ErrorHandler );
-$CGI::Session::VERSION  = '4.03';
+$CGI::Session::VERSION  = '4.05';
 $CGI::Session::NAME     = 'CGISESSID';
 $CGI::Session::IP_MATCH = 0;
 
@@ -87,7 +87,9 @@ sub _driver {
     my $self = shift;
     defined($self->{_OBJECTS}->{driver}) and return $self->{_OBJECTS}->{driver};
     my $pm = "CGI::Session::Driver::" . $self->{_DSN}->{driver};
-    return $self->{_OBJECTS}->{driver} = $pm->new( $self->{_DRIVER_ARGS} );
+    defined($self->{_OBJECTS}->{driver} = $pm->new( $self->{_DRIVER_ARGS} ))
+        or die $pm->errstr();
+    return $self->{_OBJECTS}->{driver};
 }
 
 sub _serializer     { 
@@ -403,7 +405,7 @@ sub find {
     return 1;
 }
 
-# $Id: Session.pm 225 2005-09-16 08:17:15Z sherzodr $
+# $Id: /local/cgi-session/trunk/lib/CGI/Session.pm 273 2006-02-16T03:30:35.734419Z mark  $
 
 =pod
 
