@@ -1,6 +1,6 @@
 package CGI::Session::Driver;
 
-# $Id: Driver.pm 394 2008-03-22 02:35:30Z markstos $
+# $Id: /local/cgi-session/trunk/lib/CGI/Session/Driver.pm 274 2006-03-02T02:53:47.269550Z mark  $
 
 use strict;
 #use diagnostics;
@@ -8,33 +8,22 @@ use strict;
 use Carp;
 use CGI::Session::ErrorHandler;
 
-$CGI::Session::Driver::VERSION = '4.29_1';
+$CGI::Session::Driver::VERSION = "4.04";
 @CGI::Session::Driver::ISA     = qw(CGI::Session::ErrorHandler);
 
 sub new {
     my $class = shift;
-    my $args  = shift || {};
+    my ($args) = @_;
 
-    unless ( ref $args ) {
-        croak "$class->new(): Invalid argument type passed to driver";
+    if ( $args ) {
+        unless ( ref $args ) {
+            croak "Invalid argument type passed to driver: " . Dumper($args);
+        }
+    } else {
+        $args = {};
     }
 
-    # Set defaults.
-
-    if (! $args->{TableName}) {
-        $args->{TableName} = 'sessions';
-    }
-
-    if (! $args->{IdColName}) {
-        $args->{IdColName} = 'id';
-    }
-
-    if (! $args->{DataColName}) {
-        $args->{DataColName} = 'a_session';
-    }
-
-    # perform a shallow copy of $args, to prevent modification
-    my $self = bless ({%$args}, $class);
+    my $self = bless ($args, $class);
     return $self if $self->init();
     return $self->set_error( "%s->init() returned false", $class);
 }
