@@ -1,6 +1,6 @@
 package CGI::Session::Driver::DBI;
 
-# $Id: DBI.pm 216 2005-09-01 10:52:26Z sherzodr $
+# $Id: /local/cgi-session/trunk/lib/CGI/Session/Driver/DBI.pm 274 2006-03-02T02:53:47.269550Z mark  $
 
 use strict;
 
@@ -9,21 +9,27 @@ use Carp;
 use CGI::Session::Driver;
 
 @CGI::Session::Driver::DBI::ISA = ( "CGI::Session::Driver" );
-$CGI::Session::Driver::DBI::VERSION = "1.1";
+$CGI::Session::Driver::DBI::VERSION = "1.3";
 
 
 sub init {
     my $self = shift;
-    unless ( defined $self->{Handle} ) {
+    if ( defined $self->{Handle} )  {
+        if (ref $self->{Handle} eq 'CODE') {
+            $self->{Handle} = $self->{Handle}->();
+        }
+    }
+    else {
         $self->{Handle} = DBI->connect( 
             $self->{DataSource}, $self->{User}, $self->{Password}, 
-            { RaiseError=>0, PrintError=>0, AutoCommit=>1 }
+            { RaiseError=>1, PrintError=>1, AutoCommit=>1 }
         );
         unless ( $self->{Handle} ) {
             return $self->set_error( "init(): couldn't connect to database: " . DBI->errstr );
         }
         $self->{_disconnect} = 1;
     }
+    return 1;
 }
 
 # A setter/accessor method for the table name, defaulting to 'sessions'
