@@ -1,6 +1,6 @@
 package CGI::Session::Driver::file;
 
-# $Id: file.pm 216 2005-09-01 10:52:26Z sherzodr $
+# $Id: /local/cgi-session/trunk/lib/CGI/Session/Driver/file.pm 274 2006-03-02T02:53:47.269550Z mark  $
 
 use strict;
 
@@ -8,26 +8,35 @@ use Carp;
 use File::Spec;
 use Fcntl qw( :DEFAULT :flock :mode );
 use CGI::Session::Driver;
-use vars qw( $FileName);
+use vars qw( $FileName $NoFlock );
+
+BEGIN {
+    # keep historical behavior
+
+    no strict 'refs';
+    
+    *FileName = \$CGI::Session::File::FileName;
+}
 
 @CGI::Session::Driver::file::ISA        = ( "CGI::Session::Driver" );
-$CGI::Session::Driver::file::VERSION    = "3.4";
+$CGI::Session::Driver::file::VERSION    = "3.6";
 $FileName                               = "cgisess_%s";
+$NoFlock                                = 0;
 
 sub init {
     my $self = shift;
     $self->{Directory} ||= File::Spec->tmpdir();
 
-    if (defined $CGI::Session::File::FileName) {
-        $FileName = $CGI::Session::File::FileName;
-    }
-
     unless ( -d $self->{Directory} ) {
         require File::Path;
         unless ( File::Path::mkpath($self->{Directory}) ) {
             return $self->set_error( "init(): couldn't create directory path: $!" );
         }
     }
+    
+    $self->{NoFlock} = $NoFlock unless exists $self->{NoFlock};
+    
+    return 1;
 }
 
 sub retrieve {
@@ -40,9 +49,12 @@ sub retrieve {
 
     return 0 unless -e $path;
 
-    unless ( sysopen(FH, $path, O_RDONLY) ) {
-        return $self->set_error( "retrieve(): couldn't open '$path': $!" );
-    }
+    # make certain our filehandle goes away when we fall out of scope
+    local *FH;
+
+    sysopen(FH, $path, O_RDONLY) || return $self->set_error( "retrieve(): couldn't open '$path': $!" );
+    $self->{NoFlock} || flock(FH, LOCK_SH) or return $self->set_error( "retrieve(): couldn't lock '$path': $!" );
+
     my $rv = "";
     while ( <FH> ) {
         $rv .= $_;
@@ -60,9 +72,15 @@ sub store {
     my $directory = $self->{Directory};
     my $file      = sprintf( $FileName, $sid );
     my $path      = File::Spec->catfile($directory, $file);
+    
+    # make certain our filehandle goes away when we fall out of scope
+    local *FH;
+    
     sysopen(FH, $path, O_WRONLY|O_CREAT) or return $self->set_error( "store(): couldn't open '$path': $!" );
-    flock(FH, LOCK_EX)      or return $self->set_error( "store(): couldn't lock '$path': $!" );
-    truncate(FH, 0)         or return $self->set_error( "store(): couldn't truncate '$path': $!" );
+    # prevent race condition (RT#17949)
+    truncate(FH, 0)  or return $self->set_error( "store(): couldn't truncate '$path': $!" );
+    $self->{NoFlock} || flock(FH, LOCK_EX)  or return $self->set_error( "store(): couldn't lock '$path': $!" );
+
     print FH $datastr;
     close(FH)               or return $self->set_error( "store(): couldn't close '$path': $!" );
     return 1;
@@ -109,6 +127,7 @@ sub traverse {
     return 1;
 }
 
+
 sub DESTROY {
     my $self = shift;
 }
@@ -144,7 +163,7 @@ you wish to set your own FileName template, do so before requesting for session
     $s = new CGI::Session();
 
 For backwards compatibility with 3.x, you can also use the variable name
-C<$CGI::Session::File::FileName>, which will override one above. 
+C<$CGI::Session::File::FileName>, which will override the one above. 
 
 =head2 DRIVER ARGUMENTS
 
@@ -154,6 +173,14 @@ in the SYNOPSIS section of this manual produce the same result on a UNIX machine
 
 If specified B<Directory> does not exist, all necessary directory hierarchy will be created.
 
+=head1 NOTES
+
+If your OS doesn't support flock, you should understand the risks of going without locking the session files. Since
+sessions tend to be used in environments where race conditions may occur due to concurrent access of files by 
+different processes, locking tends to be seen as a good and very necessary thing. If you still want to use this 
+driver but don't want flock, set C<$CGI::Session::Driver::file::NoFlock> to 1 or pass C<< NoFlock => 1 >> and this 
+driver will operate without locks.
+
 =head1 LICENSING
 
 For support and licensing see L<CGI::Session|CGI::Session>
