@@ -8,10 +8,8 @@ use Scalar::Util "refaddr";
 
 our $AUTOLOAD;
 our $CURRENT;
-sub ok_later (&;$);
-    
 
-$CGI::Session::Test::Default::VERSION = '4.29_1';
+$CGI::Session::Test::Default::VERSION = '1.54';
 
 =head1 CGI::Session::Test::Default
 
@@ -79,17 +77,17 @@ Run the test suite. See C<new()> for setting related options.
 sub run {
     my $self = shift;
 
-    $CURRENT = $self;
     use_ok("CGI::Session", "CGI::Session loaded successfully!");
+    $CURRENT = $self;
 
     my $sid = undef;
     FIRST: {
         ok(1, "=== 1 ===");
         my $session = CGI::Session->load() or die CGI::Session->errstr;
         ok($session, "empty session should be created");
-        ok(!$session->id, 'Id is empty');
-        ok($session->is_empty, 'Session is empty');
-        ok(!$session->is_expired, 'Session is not expired');
+        ok(!$session->id);
+        ok($session->is_empty);
+        ok(!$session->is_expired);
 
         undef $session;
 
@@ -140,14 +138,14 @@ sub run {
             eval { $session = CGI::Session->load($self->{dsn}, $sid, $self->{args}) };
 
             if ($@ || CGI::Session->errstr) {
-                Test::More::skip("couldn't load session, bailing out: SQLite/Storable support is TODO", 56);
+                skip("couldn't load session, bailing out: SQLite/Storable support is TODO", 56);
             }
 
             is($@.CGI::Session->errstr,'','survived eval without error.');
             ok($session, "Session was retrieved successfully");
             ok(!$session->is_expired, "session isn't expired yet");
 
-            is($session->id,$sid, "session IDs are consistent");
+            is($session->id,$sid, "session IDs are consistent: " . $session->id);
             ok($session->atime > $session->ctime, "ctime should be older than atime");
             ok(!$session->etime, "etime shouldn't be set yet");
 
@@ -301,7 +299,7 @@ sub run {
   
         ok($session->param("embedded_simple_and_overloaded")->[2] eq "Embedded");
         
-        ok(refaddr($session->param("embedded_simple_and_overloaded")->[2]) == refaddr($session->param("embedded_simple_and_overloaded")->[3] ),
+        ok(refaddr($session->param("embedded_simple_and_overloaded")->[2]) == refaddr($session->param("embedded_simple_and_overloaded")->[3]),
             "Overloaded objects have matching addresses");
     }
 
@@ -317,10 +315,10 @@ sub run {
         ok(ref $simple_object eq "SimpleObjectClass", "SimpleObjectClass loaded successfully");
 
         my $dsn = CGI::Session->parse_dsn($self->{dsn});
-        ok_later { $simple_object->name eq "Sherzod Ruzmetov" };
-        ok_later { $simple_object->emails(1) eq 'sherzodr@cpan.org' };
-        ok_later { $simple_object->emails(0) eq 'sherzodr@handalak.com' };
-        ok_later { $simple_object->blogs('lost+found') eq 'http://author.handalak.com/' };
+        ok($simple_object->name eq "Sherzod Ruzmetov");
+        ok($simple_object->emails(1) eq 'sherzodr@cpan.org');
+        ok($simple_object->emails(0) eq 'sherzodr@handalak.com');
+        ok($simple_object->blogs('lost+found') eq 'http://author.handalak.com/');
         ok(ref $session->param("overloaded_object") );
         ok($session->param("overloaded_object") eq "ABCDEFG", "Object is still overloaded");
         ok(overload::Overloaded($session->param("overloaded_object")), "Object is really overloaded");
@@ -330,10 +328,10 @@ sub run {
         my $simple_object2 = $session->param("embedded_simple_and_overloaded")->[1];
         ok(ref $simple_object2 eq "SimpleObjectClass", "SimpleObjectClass loaded successfully");
 
-        ok_later { $simple_object2->name eq "Sherzod Ruzmetov" };
-        ok_later { $simple_object2->emails(1) eq 'sherzodr@cpan.org' };
-        ok_later { $simple_object2->emails(0) eq 'sherzodr@handalak.com' };
-        ok_later { $simple_object2->blogs('lost+found') eq 'http://author.handalak.com/' };
+        ok($simple_object2->name eq "Sherzod Ruzmetov");
+        ok($simple_object2->emails(1) eq 'sherzodr@cpan.org');
+        ok($simple_object2->emails(0) eq 'sherzodr@handalak.com');
+        ok($simple_object2->blogs('lost+found') eq 'http://author.handalak.com/');
 
         
         ok($session->param("embedded_simple_and_overloaded")->[2] eq "Embedded");
@@ -348,39 +346,23 @@ sub run {
     $self->{test_number} = 0;
 }
 
-sub skip_or_run {
-    my $test = shift;
-    
+
+sub AUTOLOAD {
+    no strict 'refs';
+    (my $name = $AUTOLOAD) =~ s{^.*::}{};
     $CURRENT->{test_number} ++;
-
-    SKIP: {
-        if($CURRENT->{_skip}->{$CURRENT->{test_number}}) {
-            Test::More::skip("Test does not apply to this setup.", 1);
-        }
-        
-        no strict 'refs';
-        &{"Test::More::$test"}(@_);
-    }
-}
-
-sub ok { skip_or_run("ok", @_); }
-sub use_ok { skip_or_run("use_ok", @_); }
-sub is { skip_or_run("is", @_); }
-
-sub ok_later (&;$) {
-    my($code, $name) = @_;
     
-    $CURRENT->{test_number} ++;
-    $name = '' unless $name;
-
-    SKIP: {
-        if($CURRENT->{_skip}->{$CURRENT->{test_number}}) {
-            Test::More::skip("Test does not apply to this setup.", 1);
-            fail($name);
-        } else {
-            Test::More::ok($code->(), $name);
+    if(my $code = Test::More->can($name)) {
+        SKIP: {
+            if($CURRENT->{_skip}->{$CURRENT->{test_number}}) {
+                Test::More::skip("Test does not apply to this setup.", 1);
+            }
+            $code->(@_);
         }
+    } else {
+        Carp::croak("$AUTOLOAD not found");
     }
+    use strict 'refs';
 }
 
 sub DESTROY { 1; }
@@ -406,6 +388,7 @@ use overload (
     'eq'    => \&equals
 );
 
+
 sub new {
     return bless {
         str_value => $_[1]
